# Generated by Django 2.0.2 on 2018-04-14 00:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('referrals', '0005_auto_20180413_1850'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='flatreferral',
            table='flat_referral',
        ),
    ]



# Generated by Django 2.0.2 on 2018-04-13 23:13

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('referrals', '0003_auto_20180413_1631'),
    ]

    operations = [
        migrations.CreateModel(
            name='MultiLevelReferral',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('path', models.CharField(max_length=255, unique=True)),
                ('depth', models.PositiveIntegerField()),
                ('numchild', models.PositiveIntegerField(default=0)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AlterField(
            model_name='referral',
            name='referred',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='referred', to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 2.0.2 on 2018-04-13 21:31

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('referrals', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='referral',
            options={'ordering': ['id']},
        ),
        migrations.AlterField(
            model_name='referral',
            name='referred',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='referred', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='referral',
            name='referrer',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='referrer', to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 2.0.2 on 2018-04-13 23:50

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('referrals', '0004_auto_20180413_1813'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Referral',
            new_name='FlatReferral',
        ),
    ]
